use colored::{ColoredString, Colorize};
use std::process::Command;

pub fn get_git_branch() -> String {
    let git_status_cmd = Command::new("git")
        .arg("status")
        .output()
        .expect("git_status_cmd_fail");
    let git_status_output = String::from_utf8_lossy(&git_status_cmd.stdout);
    let git_err = String::from_utf8_lossy(&git_status_cmd.stderr);

    if git_err == "" {
        git_status_output.split('\n').collect::<Vec<&str>>()[0]
            .split(' ')
            .collect::<Vec<&str>>()[2]
            .to_string()
    } else {
        String::new()
    }
}

pub fn get_git_root() -> String {
    let git_repo_root_cmd = Command::new("git")
        .arg("rev-parse")
        .arg("--show-toplevel")
        .output()
        .expect("git_repo_root_cmd_fail");
    let mut git_repo_path = String::from_utf8_lossy(&git_repo_root_cmd.stdout).to_string();
    let git_repo_err = String::from_utf8_lossy(&git_repo_root_cmd.stderr);

    if git_repo_err == "" {
        let len = git_repo_path.trim_end_matches(&['\r', '\n'][..]).len();
        git_repo_path.truncate(len);
    } else {
        git_repo_path = String::new();
    }
    git_repo_path
}

pub fn get_git_repo_name(git_repo_root: &str) -> String {
    let repo_path_split: Vec<&str> = git_repo_root.split('/').collect();
    let last_index = repo_path_split.len() - 1;
    let git_repo_name = repo_path_split[last_index];

    git_repo_name.to_string()
}

pub fn get_git_char(git_branch: &str) -> ColoredString {
    match git_branch {
        "" => "".clear(),
        "main" => " 󰊢 ".truecolor(178, 98, 44),
        "master" => " 󰊢 ".truecolor(196, 132, 29),
        _ => " 󰊢 ".truecolor(82, 82, 82),
    }
}
